cmoncrawl.processor.pipeline.downloader.AsyncDownloader.unwrap
==============================================================

.. currentmodule:: cmoncrawl.processor.pipeline.downloader

.. automethod:: AsyncDownloader.unwrap